package com.fs.task.mapper;

import java.util.List;
import com.fs.task.domain.TaskMaterialInfo;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

/**
 * 材料信息Mapper接口
 * 
 * @author fs
 * @date 2026-01-04
 */
public interface TaskMaterialInfoMapper 
{
    /**
     * 查询材料信息
     * 
     * @param id 材料信息主键
     * @return 材料信息
     */
    public TaskMaterialInfo selectTaskMaterialInfoById(Long id);

    /**
     * 查询材料信息列表
     * 
     * @param taskMaterialInfo 材料信息
     * @return 材料信息集合
     */
    public List<TaskMaterialInfo> selectTaskMaterialInfoList(TaskMaterialInfo taskMaterialInfo);

    /**
     * 新增材料信息
     * 
     * @param taskMaterialInfo 材料信息
     * @return 结果
     */
    public int insertTaskMaterialInfo(TaskMaterialInfo taskMaterialInfo);

    /**
     * 修改材料信息
     * 
     * @param taskMaterialInfo 材料信息
     * @return 结果
     */
    public int updateTaskMaterialInfo(TaskMaterialInfo taskMaterialInfo);

    /**
     * 删除材料信息
     * 
     * @param id 材料信息主键
     * @return 结果
     */
    public int deleteTaskMaterialInfoById(Long id);

    /**
     * 批量删除材料信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTaskMaterialInfoByIds(Long[] ids);
    @Select("select * from  task_material_info where task_id = #{taskId} and deleted = 0")
    List<TaskMaterialInfo> selectTaskMaterialInfoByTaskId(@Param("taskId") Long taskId);

}
